@@ -11,7 +11,12 @@ class RDBService:
         self.conn = None
         self.database = database
 
+    def connect(self):
+        self.__connect()
+
     def __connect(self):
+        if self.conn is not None:
+            return
         if self.database.type == 'mssql':
             self.conn = pymssql.connect(server = self.database.host,
                                         port = self.database.port,
@@ -154,6 +159,8 @@ class MssqlService(RDBService):
     def __init__(self,database):
         super().__init__(database)
 
+    def __connect(self):
+        super().connect()
 
     def __close(self):
         super().close()
@@ -216,6 +223,11 @@ class MysqlService(RDBService):
         super().__init__(settings)
 
 
+    def __connect(self):
+        super().connect()
+
+    def __close(self):
+        super().close()
     # 根据${query}查找一条记录
     """
     query = "where a=b or (c like 'd')" sql子句
@@ -242,6 +254,13 @@ class MysqlService(RDBService):
 class PostgresqlService(RDBService):
     def __init__(self,settings):
         super().__init__(settings)
+
+
+    def __connect(self):
+        super().connect()
+
+    def __close(self):
+        super().close()
     #根据${query}查找多条记录
     """
     query = "where a=b or (c like 'd')" sql子句
